# SOIL SDK

The SOIL SDK allows users to develop and test applications that run on top of SOIL and modules and data structures that run in it.

## Install development dependencies

```
pip install -e ".[dev]"
```

## Local install

```
pip install -e .
```

### Test

```
pre-commit run --all-files
```
